Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
privacyforms_pdf / __init__.py | (no function) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | create_extractor |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | main |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | check |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | extract |  | 100% | 22 | 0 | 0 |  | 100% | 6 | 0 |  | 100%
privacyforms_pdf / cli.py | list_fields |  | 100% | 31 | 0 | 0 |  | 100% | 12 | 0 |  | 100%
privacyforms_pdf / cli.py | get_value |  | 100% | 10 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / cli.py | info |  | 100% | 8 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / cli.py | fill_form |  | 100% | 24 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
privacyforms_pdf / cli.py | (no function) |  | 100% | 42 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError.__init__ |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError.__str__ |  | 100% | 3 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry.x |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry.y |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry.width |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry.height |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry.model_dump |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFField.model_dump |  | 100% | 5 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormField.__init__ |  | 100% | 6 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormField.__repr__ |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormField.__eq__ |  | 100% | 3 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormData.__init__ |  | 100% | 5 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormData.to_json |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormData.to_dict |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.__init__ |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._get_field_type |  | 100% | 19 | 0 | 0 |  | 100% | 16 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._get_field_value |  | 100% | 17 | 0 | 0 |  | 100% | 14 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._get_field_options |  | 91% | 22 | 2 | 0 |  | 88% | 16 | 2 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.has_form |  | 100% | 5 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.extract |  | 100% | 24 | 0 | 0 |  | 100% | 6 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._get_field_pages |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._extract_geometry_from_pdf |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._extract_widgets_info |  | 83% | 29 | 5 | 0 |  | 72% | 18 | 1 |  | 79%
privacyforms_pdf / extractor.py | PDFFormExtractor._build_raw_data_structure |  | 100% | 11 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.extract_to_json |  | 100% | 6 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.list_fields |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_value |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_by_id |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_by_name |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.validate_form_data |  | 100% | 22 | 0 | 0 |  | 100% | 14 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.fill_form |  | 95% | 22 | 1 | 0 |  | 83% | 12 | 2 |  | 91%
privacyforms_pdf / extractor.py | PDFFormExtractor.fill_form_from_json |  | 100% | 10 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._validate_pdf_path |  | 100% | 4 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
privacyforms_pdf / extractor.py | get_available_geometry_backends |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | has_geometry_support |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | (no function) |  | 100% | 75 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 98% | 469 | 8 | 4 |  | 92% | 160 | 8 |  | 97%

No items found using the specified filter.